<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:fb="http://www.gribuser.ru/xml/fictionbook/2.0" xmlns:xlink="http://www.w3.org/1999/xlink">

    <xsl:output method="html" encoding="utf-8" version="4.01"
        doctype-public="-//W3C//DTD HTML 4.01 Transitional//EN"
        doctype-system="http://www.w3.org/TR/1999/REC-html401-19991224/loose.dtd" indent="yes"/>
    <xsl:param name="skipannotation" select="1"/>
    <xsl:param name="imgprefix" select="''"/>

    <xsl:template match="/">
        <html>
            <head>
                <!-- stick in a simple html stylesheet -->
                <style type="text/css">
                    body {
                        font-family: "Tahoma";
                        font-size: 11px;
                        margin: 3px;
                    }
                    table {
                        border: solid 1px #adadad;
                        border-collapse: collapse;
                        width: 100%;
                    }
                    .caption {
                        text-align: center;
                        padding: 5px;
                        font-size: 14px;
                        color: #808040;
                        font-weight: bold;
                        background: #E5E5BC;
                    }
                    td {
                        border: 1px dotted #dedede;
                        padding: 1px 0 1px 3px;
                    }</style>
                <title>
                    <xsl:value-of
                        select="/fb:FictionBook/fb:description/fb:title-info/fb:book-title"/>
                </title>
                <meta name="title">
                    <xsl:attribute name="content">
                        <xsl:value-of
                            select="/fb:FictionBook/fb:description/fb:title-info/fb:book-title"/>
                    </xsl:attribute>
                </meta>
            </head>
            <body>
                <table>
                    <col width="30%" valign="top"/>
                    <col width="70%" valign="top"/>
                    <tr>
                        <td colspan="2" class="caption">Title-info</td>
                    </tr>
                    <!-- Обложка -->
                    <xsl:choose>
                        <xsl:when
                            test="string-length(/fb:FictionBook/fb:description/fb:title-info/fb:coverpage/fb:image/@xlink:href)">
                            <tr>
                                <td>cover</td>
                                <td>
                                    <img height="120" width="80">
                                        <xsl:choose>
                                            <xsl:when
                                                test="starts-with(/fb:FictionBook/fb:description/fb:title-info/fb:coverpage/fb:image/@xlink:href,'#')">
                                                <xsl:attribute name="src">
                                                  <xsl:value-of
                                                  select="concat($imgprefix,substring(/fb:FictionBook/fb:description/fb:title-info/fb:coverpage/fb:image/@xlink:href,2))"
                                                  />
                                                </xsl:attribute>
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <xsl:attribute name="src">
                                                  <xsl:value-of
                                                  select="concat($imgprefix,/fb:FictionBook/fb:description/fb:title-info/fb:coverpage/fb:image/@xlink:href)"
                                                  />
                                                </xsl:attribute>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                    </img>
                                </td>
                            </tr>

                        </xsl:when>
                    </xsl:choose>

                    <!-- Название книги -->
                    <tr>
                        <td>book-title</td>
                        <td>
                            <xsl:value-of
                                select="/fb:FictionBook/fb:description/fb:title-info/fb:book-title"
                            />
                        </td>
                    </tr>

                    <!-- Жанры -->
                    <xsl:if test="/fb:FictionBook/fb:description/fb:title-info/fb:genre">
                        <tr>
                            <td>genre</td>
                            <td>
                                <xsl:for-each
                                    select="/fb:FictionBook/fb:description/fb:title-info/fb:genre">
                                    <xsl:value-of select="."/><br />
                                </xsl:for-each>
                            </td>
                        </tr>
                    </xsl:if>
                    
                    <!-- Серии -->
                    <xsl:if test="/fb:FictionBook/fb:description/fb:title-info/fb:sequence">
                        <tr>
                            <td>sequence</td>
                            <td>
                                <xsl:for-each
                                    select="/fb:FictionBook/fb:description/fb:title-info/fb:sequence">
                                    <xsl:call-template name="sequence"/>
                                </xsl:for-each>
                            </td>
                        </tr>
                    </xsl:if>

                    <!-- Авторы -->
                    <tr>
                        <td>author</td>
                        <td>
                            <xsl:for-each
                                select="/fb:FictionBook/fb:description/fb:title-info/fb:author">
                                <xsl:if test="position() &gt; 1">
                                    <br/>
                                </xsl:if>
                                <xsl:call-template name="author"/>
                            </xsl:for-each>
                        </td>
                    </tr>
                    
                    <!-- Аннотация -->
                    <xsl:if test="/fb:FictionBook/fb:description/fb:title-info/fb:annotation">
                        <tr>
                            <td>annotation</td>
                            <td>
                                <xsl:for-each
                                    select="/fb:FictionBook/fb:description/fb:title-info/fb:annotation/fb:p">
                                    <div>
                                        <xsl:call-template name="annotation"/>
                                    </div>
                                </xsl:for-each>
                            </td>
                        </tr>
                    </xsl:if>

                    <!-- Дата -->
                    <xsl:if test="/fb:FictionBook/fb:description/fb:title-info/fb:date">
                        <tr>
                            <td>date</td>
                            <td>
                                <xsl:value-of
                                    select="/fb:FictionBook/fb:description/fb:title-info/fb:date"/>
                            </td>
                        </tr>
                    </xsl:if>

                    <!-- Язык -->
                    <tr>
                        <td>lang</td>
                        <td>
                            <xsl:value-of
                                select="/fb:FictionBook/fb:description/fb:title-info/fb:lang"/>
                        </td>
                    </tr>

                    <!-- Язык оригинала -->
                    <xsl:if test="/fb:FictionBook/fb:description/fb:title-info/fb:src-lang">
                        <tr>
                            <td>src-lang</td>
                            <td>
                                <xsl:value-of
                                    select="/fb:FictionBook/fb:description/fb:title-info/fb:src-lang"
                                />
                            </td>
                        </tr>
                    </xsl:if>

                    <!-- Переводчики -->
                    <xsl:if test="/fb:FictionBook/fb:description/fb:title-info/fb:translator">
                        <tr>
                            <td>translator</td>
                            <td>
                                <xsl:for-each
                                    select="/fb:FictionBook/fb:description/fb:title-info/fb:translator">
                                    <xsl:if test="position() &gt; 1">
                                        <br/>
                                    </xsl:if>
                                    <xsl:call-template name="author"/>
                                </xsl:for-each>
                            </td>
                        </tr>
                    </xsl:if>

                    <!-- keywords -->
                    <xsl:if test="/fb:FictionBook/fb:description/fb:title-info/fb:keywords">
                        <tr>
                            <td>keywords</td>
                            <td>
                                <xsl:value-of
                                    select="/fb:FictionBook/fb:description/fb:title-info/fb:keywords"
                                />
                            </td>
                        </tr>
                    </xsl:if>

                    <xsl:if test="/fb:FictionBook/fb:description/fb:src-title-info">
                        <tr>
                            <td colspan="2" class="caption">Src-title-info</td>
                        </tr>
                        <!-- Обложка -->
                        <xsl:choose>
                            <xsl:when
                                test="string-length(/fb:FictionBook/fb:description/fb:src-title-info/fb:coverpage/fb:image/@xlink:href)">
                                <tr>
                                    <td>cover</td>
                                    <td>
                                        <img>
                                            <xsl:choose>
                                                <xsl:when
                                                  test="starts-with(/fb:FictionBook/fb:description/fb:src-title-info/fb:coverpage/fb:image/@xlink:href,'#')">
                                                  <xsl:attribute name="src">
                                                  <xsl:value-of
                                                  select="concat($imgprefix,substring(/fb:FictionBook/fb:description/fb:src-title-info/fb:coverpage/fb:image/@xlink:href,2))"
                                                  />
                                                  </xsl:attribute>
                                                </xsl:when>
                                                <xsl:otherwise>
                                                  <xsl:attribute name="src">
                                                  <xsl:value-of
                                                  select="concat($imgprefix,/fb:FictionBook/fb:description/fb:src-title-info/fb:coverpage/fb:image/@xlink:href)"
                                                  />
                                                  </xsl:attribute>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                        </img>
                                    </td>
                                </tr>

                            </xsl:when>
                        </xsl:choose>

                        <!-- Название книги -->
                        <tr>
                            <td>book-title</td>
                            <td>
                                <xsl:value-of
                                    select="/fb:FictionBook/fb:description/fb:src-title-info/fb:book-title"
                                />
                            </td>
                        </tr>
                        
                    <!-- Жанры -->
                    <xsl:if test="/fb:FictionBook/fb:description/fb:src-title-info/fb:genre">
                        <tr>
                            <td>genre</td>
                            <td>
                                <xsl:for-each
                                    select="/fb:FictionBook/fb:description/fb:src-title-info/fb:genre">
                                    <xsl:value-of select="."/><br />
                                </xsl:for-each>
                            </td>
                        </tr>
                    </xsl:if>

                        <!-- Серии -->
                        <xsl:if test="/fb:FictionBook/fb:description/fb:src-title-info/fb:sequence">
                            <tr>
                                <td>sequnce</td>
                                <td>
                                    <xsl:for-each
                                        select="/fb:FictionBook/fb:description/fb:src-title-info/fb:sequence">
                                        <xsl:call-template name="sequence"/>
                                    </xsl:for-each>
                                </td>
                            </tr>
                        </xsl:if>

                        <!-- Авторы -->
                        <tr>
                            <td>author</td>
                            <td>
                                <xsl:for-each
                                    select="/fb:FictionBook/fb:description/fb:src-title-info/fb:author">
                                    <xsl:if test="position() &gt; 1">
                                        <br/>
                                    </xsl:if>
                                    <xsl:call-template name="author"/>
                                </xsl:for-each>
                            </td>
                        </tr>
                        <!-- Аннотация -->
                        <xsl:if
                            test="/fb:FictionBook/fb:description/fb:src-title-info/fb:annotation">
                            <tr>
                                <td>annotation</td>
                                <td>
                                    <xsl:for-each
                                        select="/fb:FictionBook/fb:description/fb:src-title-info/fb:annotation">
                                        <xsl:call-template name="annotation"/>
                                    </xsl:for-each>
                                </td>
                            </tr>
                        </xsl:if>

                        <!-- Дата -->
                        <xsl:if test="/fb:FictionBook/fb:description/fb:src-title-info/fb:date">
                            <tr>
                                <td>date</td>
                                <td>
                                    <xsl:value-of
                                        select="/fb:FictionBook/fb:description/fb:src-title-info/fb:date"
                                    />
                                </td>
                            </tr>
                        </xsl:if>

                        <!-- Язык -->
                        <tr>
                            <td>lang</td>
                            <td>
                                <xsl:value-of
                                    select="/fb:FictionBook/fb:description/fb:src-title-info/fb:lang"
                                />
                            </td>
                        </tr>

                        <!-- Язык оригинала -->
                        <xsl:if test="/fb:FictionBook/fb:description/fb:src-title-info/fb:src-lang">
                            <tr>
                                <td>src-lang</td>
                                <td>
                                    <xsl:value-of
                                        select="/fb:FictionBook/fb:description/fb:src-title-info/fb:src-lang"
                                    />
                                </td>
                            </tr>
                        </xsl:if>

                        <!-- Переводчики -->
                        <xsl:if
                            test="/fb:FictionBook/fb:description/fb:src-title-info/fb:translator">
                            <tr>
                                <td>translator</td>
                                <td>
                                    <xsl:for-each
                                        select="/fb:FictionBook/fb:description/fb:src-title-info/fb:translator">
                                        <xsl:if test="position() &gt; 1">
                                            <br/>
                                        </xsl:if>
                                        <xsl:call-template name="author"/>
                                    </xsl:for-each>
                                </td>
                            </tr>
                        </xsl:if>

                        <!-- keywords -->
                        <xsl:if test="/fb:FictionBook/fb:description/fb:src-title-info/fb:keywords">
                            <tr>
                                <td>keywords</td>
                                <td>
                                    <xsl:value-of
                                        select="/fb:FictionBook/fb:description/fb:src-title-info/fb:keywords"
                                    />
                                </td>
                            </tr>
                        </xsl:if>
                    </xsl:if>
                    <tr>
                        <td colspan="2" class="caption">Document-info</td>
                    </tr>
                    <xsl:if test="/fb:FictionBook/fb:description/fb:document-info/fb:author">
                        <tr>
                            <td>author</td>
                            <td>
                                <xsl:for-each
                                    select="/fb:FictionBook/fb:description/fb:document-info/fb:author">
                                    <xsl:if test="position() &gt; 1">
                                        <br/>
                                    </xsl:if>
                                    <xsl:call-template name="author"/>
                                </xsl:for-each>
                            </td>
                        </tr>
                    </xsl:if>

                    <!-- программа -->
                    <xsl:if test="/fb:FictionBook/fb:description/fb:document-info/fb:program-used">
                        <tr>
                            <td>program-used</td>
                            <td>
                                <xsl:value-of
                                    select="/fb:FictionBook/fb:description/fb:document-info/fb:program-used"
                                />
                            </td>
                        </tr>
                    </xsl:if>

                    <!-- дата -->
                    <xsl:if test="/fb:FictionBook/fb:description/fb:document-info/fb:date">
                        <tr>
                            <td>date</td>
                            <td>
                                <xsl:value-of
                                    select="/fb:FictionBook/fb:description/fb:document-info/fb:date"
                                />
                            </td>
                        </tr>
                    </xsl:if>

                    <!-- src-url -->
                    <xsl:if test="/fb:FictionBook/fb:description/fb:document-info/fb:src-url">
                        <tr>
                            <td>src-url</td>
                            <td>
                                <a>
                                    <xsl:attribute name="href">
                                        <xsl:value-of
                                            select="/fb:FictionBook/fb:description/fb:document-info/fb:src-url"
                                        />
                                    </xsl:attribute>
                                    <xsl:value-of
                                        select="/fb:FictionBook/fb:description/fb:document-info/fb:src-url"
                                    />
                                </a>
                            </td>
                        </tr>
                    </xsl:if>

                    <!-- src-ocr -->
                    <xsl:if test="/fb:FictionBook/fb:description/fb:document-info/fb:src-ocr">
                        <tr>
                            <td>src-ocr</td>
                            <td>
                                <xsl:value-of
                                    select="/fb:FictionBook/fb:description/fb:document-info/fb:src-ocr"
                                />
                            </td>
                        </tr>
                    </xsl:if>

                    <!-- id -->
                    <xsl:if test="/fb:FictionBook/fb:description/fb:document-info/fb:id">
                        <tr>
                            <td>id</td>
                            <td>
                                <xsl:value-of
                                    select="/fb:FictionBook/fb:description/fb:document-info/fb:id"/>
                            </td>
                        </tr>
                    </xsl:if>

                    <!-- version -->
                    <tr>
                        <td>version</td>
                        <td>
                            <xsl:value-of
                                select="/fb:FictionBook/fb:description/fb:document-info/fb:version"
                            />
                        </td>
                    </tr>

                    <!-- history -->
                    <xsl:if test="/fb:FictionBook/fb:description/fb:document-info/fb:history">
                        <tr>
                            <td>history</td>
                            <td>
                                <xsl:for-each
                                    select="/fb:FictionBook/fb:description/fb:document-info/fb:history/fb:p">
                                    <div>
                                        <xsl:call-template name="annotation"/>
                                    </div>
                                </xsl:for-each>
                            </td>
                        </tr>
                    </xsl:if>

                    <!-- publisher -->
                    <xsl:if test="/fb:FictionBook/fb:description/fb:document-info/fb:publisher">
                        <tr>
                            <td>publisher</td>
                            <td>
                                <xsl:for-each
                                    select="/fb:FictionBook/fb:description/fb:document-info/fb:publisher">
                                    <xsl:if test="position() &gt; 1">
                                        <br/>
                                    </xsl:if>
                                    <xsl:call-template name="author"/>
                                </xsl:for-each>
                            </td>
                        </tr>
                    </xsl:if>

                    <xsl:if test="/fb:FictionBook/fb:description/fb:publish-info">
                        <tr>
                            <td colspan="2" class="caption">Publish-info</td>
                        </tr>
                        <xsl:if test="/fb:FictionBook/fb:description/fb:publish-info/fb:book-name">
                            <tr>
                                <td>book-name</td>
                                <td>
                                    <xsl:value-of
                                        select="/fb:FictionBook/fb:description/fb:publish-info/fb:book-name"
                                    />
                                </td>
                            </tr>
                        </xsl:if>
                        <xsl:if test="/fb:FictionBook/fb:description/fb:publish-info/fb:publisher">
                            <tr>
                                <td>publisher</td>
                                <td>
                                    <xsl:value-of
                                        select="/fb:FictionBook/fb:description/fb:publish-info/fb:publisher"
                                    />
                                </td>
                            </tr>
                        </xsl:if>
                        <xsl:if test="/fb:FictionBook/fb:description/fb:publish-info/fb:city">
                            <tr>
                                <td>city</td>
                                <td>
                                    <xsl:value-of
                                        select="/fb:FictionBook/fb:description/fb:publish-info/fb:city"
                                    />
                                </td>
                            </tr>
                        </xsl:if>
                        <xsl:if test="/fb:FictionBook/fb:description/fb:publish-info/fb:year">
                            <tr>
                                <td>year</td>
                                <td>
                                    <xsl:value-of
                                        select="/fb:FictionBook/fb:description/fb:publish-info/fb:year"
                                    />
                                </td>
                            </tr>
                        </xsl:if>
                        <xsl:if test="/fb:FictionBook/fb:description/fb:publish-info/fb:isbn">
                            <tr>
                                <td>isbn</td>
                                <td>
                                    <xsl:value-of
                                        select="/fb:FictionBook/fb:description/fb:publish-info/fb:isbn"
                                    />
                                </td>
                            </tr>
                        </xsl:if>
                        <xsl:if test="/fb:FictionBook/fb:description/fb:publish-info/fb:sequence">
                            <tr>
                                <td>sequence</td>
                                <td>
                                    <xsl:for-each
                                        select="/fb:FictionBook/fb:description/fb:publish-info/fb:sequence">
                                        <xsl:call-template name="sequence"/>
                                    </xsl:for-each>
                                </td>
                            </tr>
                        </xsl:if>
                    </xsl:if>

                    <xsl:if test="/fb:FictionBook/fb:description/fb:custom-info">
                        <tr>
                            <td colspan="2" class="caption">Custom-info</td>
                        </tr>
                        <tr>
                            <td>custom-info</td>
                            <td>
                                <xsl:value-of select="/fb:FictionBook/fb:description/fb:custom-info"
                                />
                            </td>
                        </tr>
                    </xsl:if>

                </table>
            </body>
        </html>
    </xsl:template>

    <!-- TEMPLATES -->

    <!-- author -->
    <xsl:template name="author">
        <xsl:value-of select="fb:last-name"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="fb:first-name"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="fb:middle-name"/>
        <xsl:if test="fb:nickname">
            <xsl:text> "</xsl:text><xsl:value-of select="fb:nickname"/>" </xsl:if>
        <xsl:if test="fb:email">
            <xsl:text> &lt;</xsl:text><xsl:value-of select="fb:email"/>&gt; </xsl:if>
        <xsl:if test="fb:home-page">
            <xsl:text> </xsl:text>
            <a>
                <xsl:attribute name="href">
                    <xsl:value-of select="fb:home-page"/>
                </xsl:attribute>
                <xsl:value-of select="fb:home-page"/>
            </a>
        </xsl:if>
    </xsl:template>

    <!-- secuence -->
    <xsl:template name="sequence">
        <xsl:value-of select="@name"/>
        <xsl:if test="@number">
            <xsl:text disable-output-escaping="no">,&#032;#</xsl:text>
            <xsl:value-of select="@number"/>
            <br/>
        </xsl:if>
        <xsl:if test="fb:sequence">
            <xsl:for-each select="fb:sequence">
                <xsl:call-template name="sequence"/>
            </xsl:for-each>
        </xsl:if>
    </xsl:template>

    <!-- annotation -->
    <xsl:template name="annotation">
        <xsl:apply-templates/>
    </xsl:template>


</xsl:stylesheet>
